@@ -51,6 +51,8 @@ class AudioEncoding(proto.Enum):
     LINEAR16 = 1
     MP3 = 2
     OGG_OPUS = 3
+    MULAW = 5
+    ALAW = 6
 
 
 class ListVoicesRequest(proto.Message):
@@ -61,14 +63,13 @@ class ListVoicesRequest(proto.Message):
         language_code (str):
             Optional. Recommended.
             `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
-            language tag. If specified, the ListVoices call will only
-            return voices that can be used to synthesize this
-            language_code. E.g. when specifying ``"en-NZ"``, you will
-            get supported ``"en-\*"`` voices; when specifying ``"no"``,
-            you will get supported ``"no-\*"`` (Norwegian) and
-            ``"nb-\*"`` (Norwegian Bokmal) voices; specifying ``"zh"``
-            will also get supported ``"cmn-\*"`` voices; specifying
-            ``"zh-hk"`` will also get supported ``"yue-\*"`` voices.
+            language tag. If not specified, the API will return all
+            supported voices. If specified, the ListVoices call will
+            only return voices that can be used to synthesize this
+            language_code. For example, if you specify ``"en-NZ"``, all
+            ``"en-NZ"`` voices will be returned. If you specify
+            ``"no"``, both ``"no-\*"`` (Norwegian) and ``"nb-\*"``
+            (Norwegian Bokmal) voices will be returned.
     """
 
     language_code = proto.Field(proto.STRING, number=1,)
