@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -101,6 +101,42 @@ class TextToSpeechAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return TextToSpeechClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> TextToSpeechTransport:
         """Returns the transport used by the client instance.
@@ -182,13 +218,10 @@ class TextToSpeechAsyncClient:
                 language tag. If not specified, the API will return all
                 supported voices. If specified, the ListVoices call will
                 only return voices that can be used to synthesize this
-                language_code. E.g. when specifying ``"en-NZ"``, you
-                will get supported ``"en-NZ"`` voices; when specifying
-                ``"no"``, you will get supported ``"no-\*"`` (Norwegian)
-                and ``"nb-\*"`` (Norwegian Bokmal) voices; specifying
-                ``"zh"`` will also get supported ``"cmn-\*"`` voices;
-                specifying ``"zh-hk"`` will also get supported
-                ``"yue-hk"`` voices.
+                language_code. For example, if you specify ``"en-NZ"``,
+                all ``"en-NZ"`` voices will be returned. If you specify
+                ``"no"``, both ``"no-\*"`` (Norwegian) and ``"nb-\*"``
+                (Norwegian Bokmal) voices will be returned.
 
                 This corresponds to the ``language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -206,7 +239,7 @@ class TextToSpeechAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([language_code])
         if request is not None and has_flattened_params:
@@ -288,7 +321,7 @@ class TextToSpeechAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([input, voice, audio_config])
         if request is not None and has_flattened_params:
